# rotalabs-accel

Inference acceleration from [Rotalabs](https://rotalabs.ai).

Speculative decoding and kernel implementations for 8.1x speedup.

**This is a placeholder package. Full implementation coming soon.**

## Links

- Website: https://rotalabs.ai
- GitHub: https://github.com/rotalabs/rotalabs-accel
- Contact: research@rotalabs.ai
